@@ -88,7 +88,10 @@ FXDEFMAP(GMPlayerManager) GMPlayerManagerMap[]={
   FXMAPFUNC(SEL_CLOSE,GMPlayerManager::ID_WINDOW,GMPlayerManager::onCmdCloseWindow),
   FXMAPFUNC(SEL_SIGNAL,GMPlayerManager::ID_CHILD,GMPlayerManager::onCmdChild),
 
-  FXMAPFUNC(SEL_COMMAND,GMPlayerManager::ID_SCROBBLER_ERROR,GMPlayerManager::onScrobblerError),
+  FXMAPFUNC(SEL_COMMAND,GMPlayerManager::ID_SCROBBLER,GMPlayerManager::onScrobblerError),
+  FXMAPFUNC(SEL_OPENED,GMPlayerManager::ID_SCROBBLER,GMPlayerManager::onScrobblerOpen),
+
+
   FXMAPFUNC(SEL_COMMAND,GMPlayerManager::ID_EQUALIZER,GMPlayerManager::onCmdEqualizer),
   FXMAPFUNC(SEL_COMMAND,GMPlayerManager::ID_SHOW_MANAGER,GMPlayerManager::onCmdShowManager),
 
@@ -741,7 +744,7 @@ FXint GMPlayerManager::run(int& argc,char** argv) {
     }
 #endif
 
-  lastfm = new GMAudioScrobbler(this,ID_SCROBBLER_ERROR);
+  lastfm = new GMAudioScrobbler(this,ID_SCROBBLER);
 
 #ifdef HAVE_DBUS
   if (sessionbus) {
@@ -920,14 +923,9 @@ void GMPlayerManager::removePlayListSources(){
   }
 
 void GMPlayerManager::download(const FXString & filename){
-#ifdef HAVE_CURL
   FXString status = "Downloading " + filename + " ...";
   GMPlayerManager::instance()->setStatus(status);
   GMFetch::download(filename);
-#else
-  show_message("Error","No buildin support for m3u/pls streams. GMM was build without libcurl.");
-  reset_track_display();
-#endif
   }
 
 FXbool GMPlayerManager::play(const FXString & filename) {
@@ -1054,12 +1052,9 @@ void GMPlayerManager::open(const FXString & uri) {
   /// Check for pls or m3u, since xine cannot handle that
   FXbool local = gm_is_local_file(filename);
   if (!local) {
-    FXString extension = FXPath::extension(GMURL::path(filename));
-    if ((comparecase(extension,"pls")==0) || (comparecase(extension,"m3u")==0)){
-      trackinfo.mrl = filename;
-      download(filename);
-      return;
-      }
+    trackinfo.mrl = filename;
+    download(filename);
+    return;
     }
 
   if (local) {
@@ -1125,13 +1120,8 @@ void GMPlayerManager::play() {
   /// Check for pls or m3u, since xine cannot handle that
   FXbool local = gm_is_local_file(trackinfo.mrl);
   if (!local) {
-
-    FXString extension = FXPath::extension(GMURL::path(trackinfo.mrl));
-    if ((comparecase(extension,"pls")==0) || (comparecase(extension,"m3u")==0)){
-      download(trackinfo.mrl);
-      reset_track_display();
-      return;
-      }
+    download(trackinfo.mrl);
+    return;
     }
 
   if (play(trackinfo.mrl)){
@@ -1205,11 +1195,8 @@ void GMPlayerManager::next() {
   /// Check for pls or m3u, since xine cannot handle that
   FXbool local = gm_is_local_file(trackinfo.mrl);
   if (!local) {
-    FXString extension = FXPath::extension(GMURL::path(trackinfo.mrl));
-    if ((comparecase(extension,"pls")==0) || (comparecase(extension,"m3u")==0)){
-      download(trackinfo.mrl);
-      return;
-      }
+    download(trackinfo.mrl);
+    return;
     }
 
   if (play(trackinfo.mrl) && gm_is_local_file(trackinfo.mrl))
@@ -1249,11 +1236,8 @@ void GMPlayerManager::prev() {
   /// Check for pls or m3u, since xine cannot handle that
   FXbool local = gm_is_local_file(trackinfo.mrl);
   if (!local) {
-    FXString extension = FXPath::extension(GMURL::path(trackinfo.mrl));
-    if ((comparecase(extension,"pls")==0) || (comparecase(extension,"m3u")==0)){
-      download(trackinfo.mrl);
-      return;
-      }
+    download(trackinfo.mrl);
+    return;
     }
 
   if (play(trackinfo.mrl) && gm_is_local_file(trackinfo.mrl))
@@ -1556,11 +1540,17 @@ long GMPlayerManager::onCmdChild(FXObject*,FXSelector,void*){
   return 1;
   }
 
+
 long GMPlayerManager::onScrobblerError(FXObject*,FXSelector,void*ptr){
   show_message(fxtr("Last.FM Error"),(const FXchar*)ptr);
   return 1;
   }
 
+long GMPlayerManager::onScrobblerOpen(FXObject*,FXSelector,void*ptr){
+  gm_open_browser((const FXchar*)ptr);
+  return 1;
+  }
+
 long GMPlayerManager::onPlayerError(FXObject*,FXSelector,void*){
   FXString errormsg;
   player->getErrorMessage(errormsg);
@@ -1576,18 +1566,21 @@ long GMPlayerManager::onCmdDownloadComplete(FXObject*,FXSelector,void*ptr){
     response = *((GMFetchResponse**)ptr);
 
   if (response) {
-     if (response->url == trackinfo.mrl ) {
+    if (response->url == trackinfo.mrl ) {
       FXStringList list;
-      FXString extension = FXPath::extension(GMURL::path(response->url));
-      if (comparecase(extension,"pls")==0 || response->content_type.find("audio/x-scpls")!=-1)
-        gm_parse_pls(response->data,list);
-      else if (comparecase(extension,"m3u")==0 || response->content_type.find("audio/mpegurl")!=-1)
+      if ((response->content_type.find("audio/mpegurl")!=-1 ||
+          response->content_type.find("audio/x-mpegurl")!=-1) && response->data.length()){
         gm_parse_m3u(response->data,list);
+        }
+      else if ((response->content_type.find("application/pls+xml")!=-1 ||
+                response->content_type.find("audio/x-scpls")!=-1) && response->data.length()) {
 
-      if (list.no())
-        play(list);
-      else
-        reset_track_display();
+        gm_parse_pls(response->data,list);
+        }
+      else {
+        list.append(response->url);
+        }
+      play(list);
       }
     else {
       reset_track_display();
