@@ -35,21 +35,22 @@
 
 /******************************************************************************/
 
+#include "ap_xml_parser.h"
+
 #include <expat.h>
 
+using namespace ap;
 
-
-
-class XSPFParser {
-protected:
-  XML_Parser   parser;
-  FXint        element;
+class XSPFParser : public XMLStream{
+public:
   FXStringList files;
   FXString     title;
-public:
-  static void xspf_element_start(void*,const XML_Char *,const XML_Char **);
-  static void xspf_element_end(void*,const XML_Char *);
-  static void xspf_element_data(void*,const XML_Char*,int);
+protected:
+  FXint        elem;
+protected:
+  FXint begin(const FXchar *,const FXchar**);
+  void data(const FXchar *,FXint len);
+  void end(const FXchar *);
 public:
   enum {
     Elem_None,
@@ -62,110 +63,83 @@ public:
 public:
   XSPFParser();
   ~XSPFParser();
-  void parse(const FXString & buffer,FXStringList & mrl,FXString & title);
   };
 
-
-XSPFParser::XSPFParser() : element(Elem_None) {
-  parser = XML_ParserCreate(NULL);
-  XML_SetUserData(parser,this);
-  XML_SetElementHandler(parser,xspf_element_start,xspf_element_end);
-  XML_SetCharacterDataHandler(parser,xspf_element_data);
+XSPFParser::XSPFParser() : elem(Elem_None) {
   }
 
-XSPFParser::~XSPFParser() {
-  XML_ParserFree(parser);
+XSPFParser::~XSPFParser(){
   }
 
-void XSPFParser::parse(const FXString & buffer,FXStringList & mrl,FXString & t) {
-  if (XML_Parse(parser,buffer.text(),buffer.length(),1)==0) {
-    // some error occured;
-    }
-  else {
-    t=title;
-    mrl.adopt(files);
-    }
-  }
-
-void XSPFParser::xspf_element_start(void * ptr,const XML_Char * name,const XML_Char**/*atts*/) {
-  XSPFParser * parser = static_cast<XSPFParser*>(ptr);
-  FXASSERT(parser);
-  switch(parser->element) {
+FXint XSPFParser::begin(const FXchar * element,const FXchar **/* attributes*/){
+  switch(elem) {
     case Elem_None:
       {
-        if (compare(name,"playlist")==0)
-          parser->element = Elem_Playlist;
+        if (compare(element,"playlist")==0) {
+          elem=Elem_Playlist;
+          return 1;
+          }
       } break;
     case Elem_Playlist:
       {
-        if (compare(name,"title")==0)
-          parser->element = Elem_Playlist_Title;
-        else if (compare(name,"trackList")==0)
-          parser->element = Elem_Playlist_TrackList;
-        } break;
-
-    case Elem_Playlist_TrackList:
-      {
-        if (compare(name,"track")==0)
-          parser->element = Elem_Playlist_TrackList_Track;
-       } break;
-
-    case Elem_Playlist_TrackList_Track:
-      {
-        if (compare(name,"location")==0)
-          parser->element = Elem_Playlist_TrackList_Track_Location;
-       } break;
-    default: break;
-    }
-  }
-
-void XSPFParser::xspf_element_end(void * ptr,const XML_Char * name) {
-  XSPFParser * parser = static_cast<XSPFParser*>(ptr);
-  FXASSERT(parser);
-  switch(parser->element) {
-    case Elem_Playlist:
-      {
-        if (compare(name,"playlist")==0)
-          parser->element=Elem_None;
+        if (compare(element,"title")==0) {
+          elem=Elem_Playlist_Title;
+          return 1;
+          }
+        else if (compare(element,"trackList")==0) {
+          elem=Elem_Playlist_TrackList;
+          return 1;
+          }
       } break;
     case Elem_Playlist_TrackList:
       {
-        if (compare(name,"trackList")==0)
-          parser->element=Elem_Playlist;
-      } break;
-    case Elem_Playlist_Title:
-      {
-        if (compare(name,"title")==0)
-          parser->element=Elem_Playlist;
+        if (compare(element,"track")==0) {
+          elem=Elem_Playlist_TrackList_Track;
+          return 1;
+          }
       } break;
     case Elem_Playlist_TrackList_Track:
       {
-        if (compare(name,"track")==0)
-          parser->element = Elem_Playlist_TrackList;
-       } break;
-    case Elem_Playlist_TrackList_Track_Location:
-      {
-        if (compare(name,"location")==0)
-          parser->element = Elem_Playlist_TrackList_Track;
-       } break;
-    default: break;
+        if (compare(element,"location")==0) {
+          elem=Elem_Playlist_TrackList_Track_Location;
+          return 1;
+          }
+      } break;
+    default: return 0; // skip
+    }
+  return 0;
+  }
+
+
+void XSPFParser::data(const FXchar* str,FXint len){
+  if (elem==Elem_Playlist_Title) {
+    title.assign(str,len);
+    }
+  else if (elem==Elem_Playlist_TrackList_Track_Location) {
+    FXString url(str,len);
+    files.append(url);
+    }
+  }
+
+void XSPFParser::end(const FXchar*) {
+  switch(elem){
+    case Elem_Playlist_TrackList_Track_Location: elem=Elem_Playlist_TrackList_Track; break;
+    case Elem_Playlist_TrackList_Track         : elem=Elem_Playlist_TrackList; break;
+    case Elem_Playlist_TrackList               :
+    case Elem_Playlist_Title                   : elem=Elem_Playlist; break;
+    case Elem_Playlist                         : elem=Elem_None; break;
     }
   }
 
 
-void XSPFParser::xspf_element_data(void * ptr,const XML_Char * data,int len) {
-  XSPFParser * parser = static_cast<XSPFParser*>(ptr);
-  FXASSERT(parser);
-  if (parser->element==Elem_Playlist_TrackList_Track_Location) {
-    FXString url(data,len);
-    parser->files.append(url);
-    }
-  else if (parser->element==Elem_Playlist_Title) {
-    parser->title.assign(data,len);
+void gm_parse_xspf(const FXString & data,FXStringList & mrl,FXString & title) {
+  XSPFParser xspf;
+  if (xspf.parse(data)) {
+    mrl=xspf.files;
+    title=xspf.title;
     }
   }
 
-
 /******************************************************************************/
 
 
@@ -296,16 +270,6 @@ void gm_parse_pls(FXString & data,FXStringList & mrl) {
 
 
 
-
-
-
-
-void gm_parse_xspf(FXString & data,FXStringList & mrl,FXString & title) {
-  XSPFParser xspf;
-  xspf.parse(data,mrl,title);
-  }
-
-
 FXbool gm_has_opengl() {
 #if FOXVERSION < FXVERSION(1,7,15)
   int glminor,glmajor;
